================
Contributing to S4CMB
================

Issues
=============
Feel free to submit issues and enhancement requests.

Contributing
=============
In general, we appreciate the "fork-and-pull" Git workflow.

* Fork the repo on GitHub
* Clone the project to your own machine and set up a new branch
* Commit changes to your branch
* Push your work back up to your fork
* Submit a Pull request so that we can review your changes

NOTE: Be sure to merge the latest from "upstream" before making a pull request!
